Learn R Programming

cocosoR (version 0.1.0)

check_input_data_cocoso: Verify if the dataset to be submitted to cocoso function is correctly formatted.

Description

Verify if the dataset to be submitted to cocoso function is correctly formatted.

Usage

check_input_data_cocoso(md_data)

Value

True if the dataset is correctly formatted and False otherwise.

Arguments

md_data

Must be a data frame with information about Criteria, Alternatives and Optimal Value. See example_cocoso.

Examples

Run this code
data(example_cocoso)
check_input_data_cocoso(example_cocoso)

Run the code above in your browser using DataLab