powered by
Verify if the dataset to be submitted to cocoso function is correctly formatted.
check_input_data_cocoso(md_data)
True if the dataset is correctly formatted and False otherwise.
Must be a data frame with information about Criteria, Alternatives and Optimal Value. See example_cocoso.
data(example_cocoso) check_input_data_cocoso(example_cocoso)
Run the code above in your browser using DataLab