Learn R Programming

cocosoR (version 0.1.0)

cocoso: Implementation of CoCoSo Method

Description

Implementation of CoCoSo Method

Usage

cocoso(md_data, parameter_alpha = 0.5)

Value

Final ranking of all alternatives from CoCoSo method. In addition, we compute and present all three aggregation strategies.

Arguments

md_data

Must be a data frame with information about Criteria, Alternatives and Optimal Value. See example_cocoso.

parameter_alpha

Parameter for third aggregation strategies.

Examples

Run this code
data(example_cocoso)
cocoso(example_cocoso)

Run the code above in your browser using DataLab