powered by
Implementation of CoCoSo Method
cocoso(md_data, parameter_alpha = 0.5)
Final ranking of all alternatives from CoCoSo method. In addition, we compute and present all three aggregation strategies.
Must be a data frame with information about Criteria, Alternatives and Optimal Value. See example_cocoso.
Parameter for third aggregation strategies.
data(example_cocoso) cocoso(example_cocoso)
Run the code above in your browser using DataLab